# humansignal

[![Release](https://img.shields.io/github/v/release/niklub/humansignal)](https://img.shields.io/github/v/release/niklub/humansignal)
[![Build status](https://img.shields.io/github/actions/workflow/status/niklub/humansignal/main.yml?branch=main)](https://github.com/niklub/humansignal/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/niklub/humansignal)](https://img.shields.io/github/commit-activity/m/niklub/humansignal)
[![License](https://img.shields.io/github/license/niklub/humansignal)](https://img.shields.io/github/license/niklub/humansignal)

This is a template repository for Python projects that use uv for their dependency management.
